selectors.py
changeset 10612 84468b90e9c1
parent 9013 b4bcabf55e77
--- a/selectors.py	Wed Sep 16 11:23:51 2015 +0200
+++ b/selectors.py	Mon Sep 14 16:03:07 2015 +0200
@@ -18,6 +18,8 @@
 
 from warnings import warn
 
+from six import string_types
+
 from logilab.common.deprecation import deprecated, class_renamed
 
 from cubicweb.predicates import *
@@ -84,7 +86,7 @@
 
     See `EntityPredicate` documentation for behaviour when row is not specified.
 
     :param *etypes: entity types (`basestring`) which should be refused
     """
     def __init__(self, *etypes):
         super(_but_etype, self).__init__()
@@ -84,7 +86,7 @@
     See `EntityPredicate` documentation for behaviour when row is not specified.
 
-    :param *etypes: entity types (`basestring`) which should be refused
+    :param *etypes: entity types (`string_types`) which should be refused
     """
     def __init__(self, *etypes):